@@ -83,10 +83,11 @@ MainWindow::MainWindow()
 	connect(this, SIGNAL(processOutput()), output, SLOT(process()));
 	connect(this, SIGNAL(fullStop()), output, SLOT(stop()));
 
-	int drows = d->rowCount();
+        int drows = d->rowCount();
 	for (int row=0; row<drows; row++) {
-		d->resizeRowToContents(row);
-	}
+                d->setRowHeight(row, 16);
+        }
+        //d->resizeRowsToContents();
 	
 	setWindowTitle(tr("nzb"));
 }
@@ -312,7 +313,8 @@ void MainWindow::populateList()
 			}
 		}
 
-		l->resizeRowToContents(row);
+                //l->resizeRowToContents(row);
+                l->setRowHeight(row, 16);
 
 		row++;
 	}
@@ -378,6 +380,15 @@ void MainWindow::start()
 	output->start(QThread::TimeCriticalPriority);
 }
 
+void MainWindow::restartDownloaders()
+{
+	for (int i=0; i<downloaders.size(); i++) {
+		if (downloaders[i]->isFinished()) {
+		    downloaders[i]->start(QThread::LowPriority);
+		}
+	}
+}
+
 void MainWindow::stop()
 {
 	startAct->setEnabled(true);
@@ -397,6 +408,8 @@ void MainWindow::stop()
 	//output->wait();
 	
 	clearData();
+
+        setWindowTitle(tr("nzb"));
 }
 
 void MainWindow::clearData()
@@ -434,7 +447,7 @@ void MainWindow::stream()
 void MainWindow::options()
 {
 	OptionsDlg *dl = new OptionsDlg(this);
-	dl->show();
+        dl->exec();
 }
 
 void MainWindow::downloadEvent(QString message, int row, int type)
@@ -444,6 +457,7 @@ void MainWindow::downloadEvent(QString message, int row, int type)
 	} else if (type == 2) {
 		l->model()->setData(l->model()->index(row, 1), (l->item(row, 1)->text()).toInt()+1);
 		totalProgress->setValue(totalProgress->value() + 1);
+                setWindowTitle(tr("nzb") + " - " + QString::number(((double)totalProgress->value() / (double)totalProgress->maximum() * 100.00), 'f' , 0) + "%");
 		
 		if (l->item(row, 1)->text() == "1") {
 			if (config->value("list/hidecompleted").toBool()) {
@@ -464,6 +478,9 @@ void MainWindow::downloadEvent(QString message, int row, int type)
 			total_speed += cur_speed.mid(0, cur_speed.length() - 5).toInt();
 		}
 		totalSpeed->setText(QString::number(total_speed)+" kB/s");
+	} else if (type == 5) {
+		d->model()->setData(d->model()->index(row, 1), message);
+		QTimer::singleShot(60000, this, SLOT(restartDownloaders()));
 	}
 }
 
@@ -504,7 +521,6 @@ OptionsDlg::OptionsDlg(QWidget *parent) : QDialog(parent)
 	connect(ui.mediaBrowse, SIGNAL(clicked()), this, SLOT(browseMedia()));
 	
 	connect(ui.subfolders, SIGNAL(stateChanged(int)), this, SLOT(enableGuess(int)));
-	connect(ui.ssl, SIGNAL(stateChanged(int)), this, SLOT(sslChange(int)));
 	connect(ui.use_file, SIGNAL(clicked()), this, SLOT(useFile()));
 	
 	QSettings *config = ((MainWindow*)parent)->getConfig();
@@ -573,6 +589,8 @@ OptionsDlg::OptionsDlg(QWidget *parent) : QDialog(parent)
 	} else {
 		ui.stream->setCheckState(Qt::Unchecked);
 	}
+
+        connect(ui.ssl, SIGNAL(stateChanged(int)), this, SLOT(sslChange(int)));
 }
 
 void OptionsDlg::accept()
@@ -599,12 +617,12 @@ void OptionsDlg::accept()
 		
 	config->sync();
 	
-	close();
+        QDialog::accept();
 }
 
 void OptionsDlg::reject()
 {
-	close();
+        QDialog::reject();
 }
 
 void OptionsDlg::browseSave()
